sequencetools.Matrix
====================

.. inheritance-diagram:: abjad.tools.sequencetools.Matrix.Matrix.Matrix
   :private-bases:

.. autoclass:: abjad.tools.sequencetools.Matrix.Matrix.Matrix

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.sequencetools.Matrix.Matrix.Matrix.columns

.. autoattribute:: abjad.tools.sequencetools.Matrix.Matrix.Matrix.rows

Special Methods
---------------

.. automethod:: abjad.tools.sequencetools.Matrix.Matrix.Matrix.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.sequencetools.Matrix.Matrix.Matrix.__eq__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.sequencetools.Matrix.Matrix.Matrix.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.sequencetools.Matrix.Matrix.Matrix.__getitem__

.. automethod:: abjad.tools.sequencetools.Matrix.Matrix.Matrix.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.sequencetools.Matrix.Matrix.Matrix.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.sequencetools.Matrix.Matrix.Matrix.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.sequencetools.Matrix.Matrix.Matrix.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.sequencetools.Matrix.Matrix.Matrix.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.sequencetools.Matrix.Matrix.Matrix.__repr__

.. automethod:: abjad.tools.sequencetools.Matrix.Matrix.Matrix.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.sequencetools.Matrix.Matrix.Matrix.__str__

   .. note:: Inherited from `__builtin__.object`
